@@ -10,11 +10,12 @@ aknn.reg <- function(xnew, y, x, a = seq(0.1, 1, by = 0.1), k = 2:10, apostasi =
   D <- dim(y)[2]
   names <- paste("alpha", a)
   est <- sapply(names, function(x) NULL)
+  
   if ( rann ) {
     di <- RANN::nn2( data = x, query = xnew, k = max(k) )$nn.idx
   } else  di <- Rfast::dista( xnew, x, type = apostasi, k = max(k), index = TRUE, square = TRUE )
-  for ( i in 1:la ) {
-    est[[ i ]] <- Compositional::frechet2( y, di, a[i], k )
-  }
+  
+  for ( i in 1:la ) est[[ i ]] <- Compositional::frechet2( y, di, a[i], k )
+    
   est
 }
