@@ -1,44 +1,24 @@
 kent.contour <- function(G, param, n = 100, x = NULL, cont.line = FALSE) {
-  ## a are the estimated Dirichlet parameters
-  ## n shows the number of points at which the density is calculated
-  ## so, n^2 points are used.
-  ## x should be a 3-part compositional data or NULL for no data
+
   nam <- c("X1", "X2", "X3")
   x1 <- seq(0.001, 0.999, length = n)  ## coordinates of x
   sqrt3 <- sqrt(3)
   x2 <- seq(0.001, sqrt3/2 - 1e-03, length = n)  ## coordinates of y
-  mat <- matrix(nrow = n, ncol = n)
+  oop <- options(warn = -1)
+  on.exit( options(oop) )
 
-  for ( i in 1:c(n/2) ) {
-    for (j in 1:n) {
-      if ( x2[j] <= sqrt3 * x1[i] ) {
-        ## This checks if the point will lie inside the triangle
-        ## the next three lines invert the points which lie inside
-        ## the triangle back into the composition in S^2
-        w3 <- 2 * x2[j] / sqrt3
-        w2 <- x1[i] - x2[j]/sqrt3
-        w1 <- 1 - w2 - w3
-        y <- sqrt( c(w1, w2, w3) )
-        can <- Directional::dkent(y, G, param)
-        if (abs(can) < Inf)  mat[i, j] <- can
-      }
-    }
-  }
-  for (i in c(n/2 + 1):n) {
-    for (j in 1:n) {
-      ## This checks if the point will lie inside the triangle
-      if ( x2[j] <= sqrt3 - sqrt3 * x1[i] ) {
-        ## the next three lines invert the points which lie inside
-        ## the triangle back into the composition in S^2
-        w3 <- 2 * x2[j] / sqrt3
-        w2 <- x1[i] - x2[j]/sqrt3
-        w1 <- 1 - w2 - w3
-        y <- sqrt( c(w1, w2, w3) )
-        can <- Directional::dkent(y, G, param)
-        if (abs(can) < Inf)  mat[i, j] <- can
-      }
-    }
+  wa <- NULL
+  for ( i in 1:n ) {
+    w3 <- 2 * x2 / sqrt3
+    w2 <- x1[i] - x2/sqrt3
+    w1 <- 1 - w2 - w3
+    wa <- rbind(wa, cbind(w1, w2, w3) )
   }
+
+  y <- sqrt(wa)
+  can <- Directional::dkent(y, G, param)
+  mat <- matrix(can, byrow = TRUE, nrow = n, ncol = n)
+
  # Create triangle corners
   b1 <- c(0.5, 0, 1, 0.5)
 
