@@ -49,6 +49,9 @@ kl.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL, tol = 1e-07, maxite
       }  ##  end  for (i in 1:B) {
 	  
     } else {
+	  oop <- options(warn = -1)
+      on.exit( options(oop) )
+      requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
       cl <- parallel::makePSOCKcluster(ncores)
       doParallel::registerDoParallel(cl)
       X <- model.matrix(y~., data.frame(x) )
