@@ -11,7 +11,7 @@ klcompreg.boot <- function(y, x, der, der2, id, b1, n, p, d, tol = 1e-07, maxite
   }
   b2 <- b1 + solve(der2, der)
   k <- 2
-  
+
   res <- try(
   while ( sum( abs(b2 - b1) ) > tol  &  k < maxiters) {
     k <- k + 1
@@ -30,8 +30,8 @@ klcompreg.boot <- function(y, x, der, der2, id, b1, n, p, d, tol = 1e-07, maxite
     b2 <- b1 + solve(der2, der)
   },
   silent = TRUE)
-  
-  if ( class(res) == "try-error" )   b2 <- b1
+
+  if ( identical( class(res), "try-error") )   b2 <- b1
    m <- cbind(1, m1)
    m <- m / Rfast::rowsums(m)
    Y <- cbind( 1 - Rfast::rowsums(y), y )
