@@ -63,6 +63,9 @@ ols.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
 
     } else {
       runtime <- proc.time()
+	  oop <- options(warn = -1)
+      on.exit( options(oop) )
+      requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
       betaboot <- matrix(nrow = B, ncol = length(ini) )
       cl <- parallel::makePSOCKcluster(ncores)
       doParallel::registerDoParallel(cl)
